@@ -47,21 +47,12 @@ Credits
 :Author:  Ed Schofield
 :Sponsor: Python Charmers Pty Ltd, Australia, and Python Charmers Pte
           Ltd, Singapore. http://pythoncharmers.com
-:Others:  - The backported ``super()`` and ``range()`` functions are
-            derived from Ryan Kelly's ``magicsuper`` module and Dan
-            Crosta's ``xrange`` module.
-          - The ``futurize`` script uses ``lib2to3`` and fixers from
-            Joe Amenta's ``lib3to2`` and Armin Ronacher's ``python-modernize``.
-          - The ``python_2_unicode_compatible`` decorator is from
-            Django. The ``implements_iterator`` and ``with_metaclass``
-            decorators are from Jinja2.
-          - Documentation is generated using ``sphinx`` and styled using
-            ``sphinx-bootstrap-theme``.
+:Others:  See docs/credits.rst or http://python-future.org/credits.html
 
 
 Licensing
 ---------
-Copyright 2013 Python Charmers Pty Ltd, Australia.
+Copyright 2013-2014 Python Charmers Pty Ltd, Australia.
 The software is distributed under an MIT licence. See LICENSE.txt.
 
 """
@@ -71,7 +62,7 @@ __all__ = []
 
 __ver_major__ = 0
 __ver_minor__ = 10
-__ver_patch__ = 1
+__ver_patch__ = 2
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__, __ver_minor__,
                               __ver_patch__, __ver_sub__)
