@@ -10,6 +10,7 @@ from future.tests.base import unittest
 import textwrap
 from subprocess import Popen, PIPE
 from numbers import Integral
+from decimal import Decimal
 
 
 class TestBuiltins(unittest.TestCase):
@@ -34,6 +35,7 @@ class TestBuiltins(unittest.TestCase):
         test fail unless isinstance() is defined appropriately:
         """
         self.assertTrue(isinstance(0, int))
+        self.assertTrue(isinstance(int(1), int))
         self.assertFalse(isinstance(1.0, int))
 
     def test_isinstance_Integral(self):
@@ -47,6 +49,7 @@ class TestBuiltins(unittest.TestCase):
         Py2's long doesn't inherit from int!
         """
         self.assertTrue(isinstance(10**100, int))
+        self.assertTrue(isinstance(int(2**64), int))
         if not PY3:
             self.assertTrue(isinstance(long(1), int))
         # Note: the following is a SyntaxError on Py3:
@@ -61,6 +64,42 @@ class TestBuiltins(unittest.TestCase):
         self.assertTrue(isinstance(u'string', str))
         self.assertFalse(isinstance(u'string', bytes))
 
+    @unittest.expectedFailure
+    def test_type(self):
+        """
+        The following fails when passed a unicode string on Python
+        (including when unicode_literals is in effect) and fails when
+        passed a byte-string on Python 3. So type() always wants a native
+        string as the first argument.
+
+        TODO: maybe provide a replacement that works identically on Py2/3?
+        """
+        mytype = type('blah', (dict,), {"old": 1, "new": 2})
+        d = mytype()
+        self.assertTrue(isinstance(d, mytype))
+        self.assertTrue(isinstance(d, dict))
+
+    def test_isinstance_tuple_of_types(self):
+        # These two should be equivalent, even if ``int`` is a special
+        # backported type.
+        label = 1
+        self.assertTrue(isinstance(label, (float, Decimal)) or
+                        isinstance(label, int))
+        self.assertTrue(isinstance(label, (float, Decimal, int)))
+        self.assertTrue(isinstance(10**100, (float, Decimal, int)))
+
+        self.assertTrue(isinstance(b'blah', (str, bytes)))
+        self.assertTrue(isinstance(b'blah', (bytes, float, int)))
+
+        self.assertFalse(isinstance(b'blah', (str, Decimal, float, int)))
+
+        self.assertTrue(isinstance('blah', (str, Decimal, float, int)))
+        self.assertTrue(isinstance(u'blah', (Decimal, float, int, str)))
+
+        self.assertFalse(isinstance('blah', (bytes, Decimal, float, int)))
+
+    @unittest.skipIf(sys.version_info[:2] == (2, 6),
+                     'not yet implemented for Py2.6')
     def test_round(self):
         """
         Note that the Python 2.x round() function fails these tests. The
